@@ -55,6 +55,7 @@ class OpenStackProvider(Provider):
     def __init__(self):
         """Object initialization."""
         self._name = PROVISIONER_KEY
+        self.display_name = "OpenStack"
         self.flavors = {}
         self.flavors_by_ref = {}
         self.images = {}
@@ -83,7 +84,7 @@ class OpenStackProvider(Provider):
         * available flavors
         * networks
         * network availabilities (number of available IPs for networks)
-        * images which were defined in `image_names` option
+        * images which were defined in `images` option
         * account limits (max and current usage of vCPUs, memory, ...)
         """
         # session expects that credentials will be set via env variables
@@ -102,7 +103,7 @@ class OpenStackProvider(Provider):
         logger.info(f"Login duration {login_duration}")
 
         object_start = datetime.now()
-        flavors, images, limits, networks, ips = await asyncio.gather(
+        _, _, limits, _, _ = await asyncio.gather(
             self.load_flavors(),
             self.load_images(image_names),
             self.nova.limits.show(),
@@ -368,15 +369,6 @@ class OpenStackProvider(Provider):
             logger.warning(f"Server '{uuid}' not found, probably already deleted")
             pass
 
-    def parse_errors(self, server_results):
-        """Parse provisioning errors from provider result."""
-        errors = []
-        for res in server_results:
-            if self.STATUS_MAP.get(res["status"], STATUS_OTHER) == STATUS_ERROR:
-                errors.append(res)
-
-        return errors
-
     async def wait_till_provisioned(
         self, instance, timeout=None, poll_sleep=None, poll_sleep_initial=None
     ):
@@ -433,10 +425,10 @@ class OpenStackProvider(Provider):
 
         return server
 
-    async def delete_host(self, host):
+    async def delete_host(self, host_id):
         """Issue deletion of host(server) from OpenStack."""
-        logger.info(f"Deleting OpenStack host {host.id}")
-        await self.delete_server(host._id)
+        logger.info(f"Deleting OpenStack host {host_id}")
+        await self.delete_server(host_id)
         return True
 
     def prov_result_to_host_data(self, prov_result):
