@@ -36,9 +36,8 @@ class AWSTransformer(Transformer):
 
     async def init_provider(self):
         """Initialize associate provider."""
-        images = self.config["images"].values()
         await self._provider.init(
-            image_names=images,
+            ami_ids=self.config["images"].values(),
             ssh_key=self.config["keypair"],
             sec_group=self.config["security_group"],
             instance_tags=self.config["instance_tags"],
@@ -51,15 +50,24 @@ class AWSTransformer(Transformer):
         return get_config_value(self.config["flavors"], host["group"])
 
     def _get_image(self, os):
-        """Get image name by OS name from provisioning config."""
-        return get_config_value(self.config["images"], os)
+        """
+        Get image name by OS name from provisioning config.
+
+        Returns:
+            1. image by the os key
+            2. default from the images if os is not found in keys
+            3. os name if default is not specified for images.
+        """
+        return get_config_value(self.config["images"], os, os)
 
     def create_host_requirement(self, host):
         """Create single input for AWS provisioner."""
+        required_image = host.get("image") or self._get_image(host["os"])
         return {
             "name": host["name"],
             "flavor": self._get_flavor(host),
-            "image": self._get_image(host["os"]),
+            "image": required_image,
+            "meta_image": "image" in host,
         }
 
     def create_host_requirements(self):
